@@ -21,8 +21,8 @@ class RethinkDBClient(BaseStorageClient):
         )
 
         db_list = await r.db_list().run(self._connection)
+        self._buckets.extend(self._config.db)
         for db in self._config.db:
-            self._buckets.append(db)
             if db not in db_list:
                 await r.db_create(db).run(self._connection)
 
